@@ -109,32 +109,32 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s!<META CONTENT =(.+?) HTTP-EQUIV =(.+?)>!!ig;
 	$lines =~ s!<META HTTP-EQUIV=(.+?) CONTENT=(.+?)>!!ig;
 	$lines =~ s!<META HTTP-EQUIV =(.+?) CONTENT =(.+?)>!!ig;
-	$lines =~ s/html/html/ig;	 
+	$lines =~ s/\bHTML\b/html/ig;	 
 	$lines =~ s/TITLE =|TITLE=/title=/ig;	 	
 	$lines =~ s/<TITLE/<title/ig;
 	$lines =~ s/<\/TITLE/<\/title/ig;
 	$lines =~ s/CONTENT =|CONTENT=/content=/ig;		
-	$lines =~ s/META/meta/ig;
+	$lines =~ s/\bMETA\b/meta/ig;
 	$lines =~ s/<META (.*?)>$/<meta $1\/>/ig;
 	$lines =~ s/<LINK (.+?)>/<link $1\/>/ig;
-	$lines =~ s/NAME/name/ig;	
+	$lines =~ s/\bNAME\b/name/ig;	
 	$lines =~ s/<HEAD/<head/ig;
 	$lines =~ s/<\/HEAD/<\/head/ig;
 	$lines =~ s/<LINK/<link/ig;	
-	$lines =~ s/HREF/href/ig;
+	$lines =~ s/\bHREF\b/href/ig;
 	$lines =~ s/TYPE =|TYPE=/type=/ig;	
 	$lines =~ s/REL =|REL=/rel=/ig;
 	$lines =~ s/MEDIA =|MEDIA=/media=/ig;		
-	$lines =~ s/BODY/body/ig;	
+	$lines =~ s/\bBODY\b/body/ig;	
 	$lines =~ s/<P>/<p>/ig;	 	
 	$lines =~ s/<\/P>/<\/p>/ig;	
 	$lines =~ s!<IMG (.+?)>!<img $1\/>!mig;
 	$lines =~ s/SRC/src/ig;
 	$lines =~ s/CLASS =|CLASS=/class=/ig;
 	$lines =~ s/ALT =|ALT=/alt=/ig;
-	$lines =~ s/HEIGHT/height/ig;
-	$lines =~ s/WIDTH/width/ig;
-	$lines =~ s/DIV/div/ig;
+	$lines =~ s/\bHEIGHT\b/height/ig;
+	$lines =~ s/\bWIDTH\b/width/ig;
+	$lines =~ s/\bDIV\b/div/ig;
 	$lines =~ s/<SPAN/<span/ig;
 	$lines =~ s/<\/SPAN/<\/span/ig;
 	$lines =~ s/ID =|ID=/id=/ig;
@@ -154,14 +154,14 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/UL>/<\/ul>/ig;		
 	$lines =~ s/<B>/<b>/ig;	 	
 	$lines =~ s/<\/B>/<\/b>/ig;		
-	$lines =~ s/MENU /menu /ig;
-	$lines =~ s/SMALL/small/ig;
+	$lines =~ s/\bMENU\b/menu/ig;
+	$lines =~ s/\bSMALL\b/small/ig;
 	$lines =~ s/<\/UL/<\/ul/ig;
 	$lines =~ s/<\/ACRONYM/<\/acronym/ig;
 	$lines =~ s/<ACRONYM/<acronym/ig;
 	$lines =~ s/<\/ABBR/<\/abbr/ig;
 	$lines =~ s/<ABBR/<abbr/ig;	
-	$lines =~ s/BLOCKQUOTE/blockquote/ig;
+	$lines =~ s/\bBLOCKQUOTE\b/blockquote/ig;
 	$lines =~ s/<ADDRESS/<address/ig;
 	$lines =~ s/<\/ADDRESS/<\/address/ig;	
 	$lines =~ s/<CITE/<cite/ig;
@@ -194,7 +194,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/PARAM/<\/param/ig;	
 	$lines =~ s/<OBJECT/<object/ig;
 	$lines =~ s/<\/OBJECT/<\/object/ig;	
-	$lines =~ s/BIG/big/ig;
+	$lines =~ s/\bBIG\b/big/ig;
 	$lines =~ s/<SUP/<sup/ig;
 	$lines =~ s/<\/SUP/<\/sup/ig;	
 	$lines =~ s/<SUB/<sub/ig;
@@ -209,14 +209,14 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/BDO/<\/bdo/ig;	
 	$lines =~ s/<LEGEND/<legend/ig;
 	$lines =~ s/<\/LEGEND/<\/legend/ig;	
-	$lines =~ s/OPTION/option/ig;
+	$lines =~ s/\bOPTION\b/option/ig;
 	$lines =~ s/<AREA/<area/ig;
 	$lines =~ s/<\/AREA/<\/area/ig;	
 	$lines =~ s/<MAP/<map/ig;
 	$lines =~ s/<\/MAP/<\/map/ig;	
-	$lines =~ s/ISMAP/ismap/ig;
-	$lines =~ s/NOSCRIPT/noscript/ig;
-	$lines =~ s/SCRIPT/script/ig;
+	$lines =~ s/\bISMAP\b/ismap/ig;
+	$lines =~ s/\bNOSCRIPT\b/noscript/ig;
+	$lines =~ s/\bSCRIPT\b/script/ig;
 	$lines =~ s/<BASE/<base/ig;
 	$lines =~ s/<\/BASE/<\/base/ig;	
 	$lines =~ s/<RUBY/<ruby/ig;
@@ -241,18 +241,18 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/BLINK/<\/blink/ig;		
 	$lines =~ s/<EMBED/<embed/ig;
 	$lines =~ s/<\/EMBED/<\/embed/ig;	
-	$lines =~ s/PLUGINSPAGE/pluginspage/ig;
-	$lines =~ s/PLUGINURL/pluginurl/ig;
-	$lines =~ s/HIDDEN/hidden/ig;
-	$lines =~ s/AUTOSTART/autostart/ig;
-	$lines =~ s/LOOP/loop/ig;
-	$lines =~ s/PLAYCOUNT/playcount/ig;
+	$lines =~ s/\bPLUGINSPAGE\b/pluginspage/ig;
+	$lines =~ s/\bPLUGINURL\b/pluginurl/ig;
+	$lines =~ s/\bHIDDEN\b/hidden/ig;
+	$lines =~ s/\bAUTOSTART\b/autostart/ig;
+	$lines =~ s/\bLOOP\b/loop/ig;
+	$lines =~ s/\bPLAYCOUNT\b/playcount/ig;
 	$lines =~ s/VOLUME =|VOLUME=/volume=/ig;
-	$lines =~ s/CONTROLS =|VOLUME=/controls=/ig;
-	$lines =~ s/CONTROLLER= |VOLUME=/controller=/ig;
-	$lines =~ s/MASTERSOUND/mastersound/ig;
-	$lines =~ s/STARTTIME/starttime/ig;
-	$lines =~ s/ENDTIME/endtime/ig;	
+	$lines =~ s/CONTROLS =|CONTROLS=/controls=/ig;
+	$lines =~ s/CONTROLLER= |CONTROLLER=/controller=/ig;
+	$lines =~ s/\bMASTERSOUND\b/mastersound/ig;
+	$lines =~ s/\bSTARTTIME\b/starttime/ig;
+	$lines =~ s/\bENDTIME\b/endtime/ig;	
 	$lines =~ s/ALIGN =|ALIGN=/align=/ig; 	
 	$lines =~ s/SUMMARY =|VOLUME=/summary=/ig; 
 	$lines =~ s/DIR =|DIR=/dir=/ig; 		
@@ -268,17 +268,17 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/TH>/<\/th>/ig;
 	$lines =~ s/<TR/<tr/ig;			
 	$lines =~ s/<\/TR/<\/tr/ig;	
-	$lines =~ s/TBODY/tbody/ig;	
+	$lines =~ s/\bTBODY\b/tbody/ig;	
 	$lines =~ s/<CAPTION/<caption/ig;
 	$lines =~ s/<\/CAPTION/<\/caption/ig;		
-	$lines =~ s/THEAD/thead/ig;	
-	$lines =~ s/TFOOT/tfoot/ig;	
-	$lines =~ s/COLGROUP/colgroup/ig;	
+	$lines =~ s/\bTHEAD\b/thead/ig;	
+	$lines =~ s/\bTFOOT\b/tfoot/ig;	
+	$lines =~ s/\bCOLGROUP\b/colgroup/ig;	
 	$lines =~ s/<COL/<col/ig;
 	$lines =~ s/<\/COL/<\/col/ig;			
 	$lines =~ s/ROWSPAN =|ROWSPAN=/rowspan=/ig; 
 	$lines =~ s/COLSPAN =|COLSPAN=/colspan=/ig; 
-	$lines =~ s/NOWRAP/nowrap/ig; 
+	$lines =~ s/\bNOWRAP\b/nowrap/ig; 
 	$lines =~ s/AXIS =|AXIS=/axis=/ig; 
 	$lines =~ s/STYLE =|STYLE=/style=/ig; 
 	$lines =~ s/BGCOLOR =|BGCOLOR=/bgcolor=/ig; 
@@ -324,6 +324,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/LABEL/<\/label/ig;	
 	$lines =~ s/ACCESSKEY =|ACCESSKEY=/accesskey=/ig;
 	$lines =~ s/METHOD =|METHOD=/method=/ig;
+	$lines =~ s/method=\"(\w+)\"/method=\"\L$1\"/ig; 			
 	$lines =~ s/ACTION =|ACTION=/action=/ig;
 	$lines =~ s/ENCTYPE =|ENCTYPE=/enctype=/ig;
 	$lines =~ s/<LEGEND/<legend/ig;
